@@ -19,8 +19,8 @@ DEFAULT_CONFIG = {
     'shell_type': 'bash',
     'pip_options': '-q --download-cache /sb/pip_cache',
     'sdk_runner_command': ['/usr/bin/python', '-m', 'sbgsdk.cli'],
-    'schema_server_url': 'https://lair.sbgenv.com:1180',
-    'file_server_url': 'lair.sbgenv.com',
+    'schema_server_url': 'https://sdk-alpha.sbgenomics.com:1180',
+    'file_server_url': 'sdk-alpha.sbgenomics.com',
     'vs_client_path': '/opt/vsclient/bin/vsclient.sh',
 
     'docker_registry_name': 'docker.sbgenomics.com:8888',
